.. _all-salt.modules:

=================
execution modules
=================

.. admonition:: Virtual modules

    .. toctree::

        salt.modules.group
        salt.modules.pkg
        salt.modules.user

.. currentmodule:: salt.modules

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    acme
    aliases
    alternatives
    apache
    apcups
    apf
    aptpkg
    archive
    artifactory
    at
    augeas_cfg
    aws_sqs
    bamboohr
    bcache
    beacons
    bigip
    blockdev
    bluez
    boto_apigateway
    boto_asg
    boto_cfn
    boto_cloudtrail
    boto_cloudwatch
    boto_cloudwatch_event
    boto_cognitoidentity
    boto_datapipeline
    boto_dynamodb
    boto_ec2
    boto_elasticache
    boto_elasticsearch_domain
    boto_elb
    boto_iam
    boto_iot
    boto_kms
    boto_lambda
    boto_rds
    boto_route53
    boto_s3_bucket
    boto_secgroup
    boto_sns
    boto_sqs
    boto_vpc
    bower
    bridge
    bsd_shadow
    btrfs
    cabal
    cassandra
    cassandra_cql
    celery
    ceph
    chassis
    chef
    chocolatey
    chronos
    cisconso
    cloud
    cmdmod
    composer
    config
    consul
    container_resource
    cp
    cpan
    cron
    csf
    cyg
    cytest
    daemontools
    data
    ddns
    deb_apache
    deb_postgres
    debbuild
    debconfmod
    debian_ip
    debian_service
    defaults
    devmap
    dig
    disk
    djangomod
    dnsmasq
    dnsutil
    dockercompose
    dockerio
    dockerng
    dpkg
    drac
    dracr
    drbd
    ebuild
    eix
    elasticsearch
    environ
    eselect
    esxi
    etcd_mod
    ethtool
    event
    extfs
    file
    firewalld
    freebsd_sysctl
    freebsdjail
    freebsdkmod
    freebsdpkg
    freebsdports
    freebsdservice
    gem
    genesis
    gentoo_service
    gentoolkitmod
    git
    github
    glance
    glusterfs
    gnomedesktop
    gpg
    grains
    groupadd
    grub_legacy
    guestfs
    hadoop
    haproxyconn
    hashutil
    hg
    hipchat
    hosts
    htpasswd
    http
    ifttt
    ilo
    img
    incron
    influx
    influx08
    infoblox
    ini_manage
    inspectlib
    inspectlib.collector
    inspectlib.dbhandle
    inspectlib.entities
    inspectlib.exceptions
    inspectlib.fsdb
    inspectlib.kiwiproc
    inspectlib.query
    inspector
    introspect
    ipmi
    ipset
    iptables
    iwtools
    jboss7
    jboss7_cli
    jenkins
    junos
    k8s
    kapacitor
    kerberos
    key
    keyboard
    keystone
    kmod
    launchctl
    layman
    ldap3
    ldapmod
    linux_acl
    linux_ip
    linux_lvm
    linux_sysctl
    localemod
    locate
    logadm
    logrotate
    lvs
    lxc
    mac_assistive
    mac_brew
    mac_defaults
    mac_desktop
    mac_group
    mac_keychain
    mac_package
    mac_pkgutil
    mac_ports
    mac_power
    mac_service
    mac_shadow
    mac_softwareupdate
    mac_sysctl
    mac_system
    mac_timezone
    mac_user
    mac_xattr
    makeconf
    marathon
    match
    mdadm
    mdata
    memcached
    mine
    minion
    mod_random
    modjk
    mongodb
    monit
    moosefs
    mount
    mssql
    munin
    mysql
    nacl
    nagios
    nagios_rpc
    napalm_bgp
    napalm_network
    napalm_ntp
    napalm_probes
    napalm_route
    napalm_snmp
    napalm_users
    netaddress
    netbsd_sysctl
    netbsdservice
    netscaler
    network
    neutron
    nfs3
    nftables
    nginx
    nova
    npm
    nspawn
    nxos
    omapi
    openbsd_sysctl
    openbsdpkg
    openbsdrcctl
    openbsdservice
    openstack_config
    openstack_mng
    openvswitch
    opkg
    oracle
    osquery
    pacman
    pagerduty
    pagerduty_util
    pam
    parallels
    parted
    pcs
    pecl
    philips_hue
    pillar
    pip
    pkg_resource
    pkgin
    pkgng
    pkgutil
    portage_config
    postfix
    postgres
    poudriere
    powerpath
    proxy
    ps
    publish
    puppet
    pushbullet
    pushover_notify
    pw_group
    pw_user
    pyenv
    qemu_img
    qemu_nbd
    quota
    rabbitmq
    raet_publish
    rallydev
    random_org
    rbenv
    rdp
    redismod
    reg
    rest_package
    rest_sample_utils
    rest_service
    restartcheck
    ret
    rh_ip
    rh_service
    riak
    rpm
    rpmbuild
    rsync
    runit
    rvm
    s3
    s6
    salt_proxy
    saltcloudmod
    saltutil
    schedule
    scsi
    sdb
    seed
    selinux
    sensors
    serverdensity_device
    service
    servicenow
    shadow
    slack_notify
    slsutil
    smartos_imgadm
    smartos_nictagadm
    smartos_virt
    smartos_vmadm
    smbios
    smf
    smtp
    solaris_fmadm
    solaris_group
    solaris_shadow
    solaris_system
    solaris_user
    solarisips
    solarispkg
    solr
    splunk
    splunk_search
    sqlite3
    ssh
    ssh_package
    ssh_service
    snapper
    state
    status
    stormpath
    supervisord
    svn
    swift
    sysbench
    sysfs
    syslog_ng
    sysmod
    sysrc
    system
    system_profiler
    systemd
    telemetry
    temp
    test
    testinframod
    test_virtual
    timezone
    tls
    tomcat
    trafficserver
    tuned
    twilio_notify
    udev
    upstart
    uptime
    useradd
    uwsgi
    varnish
    vbox_guest
    vboxmanage
    victorops
    virt
    virtualenv_mod
    vsphere
    win_autoruns
    win_certutil
    win_dacl
    win_disk
    win_dism
    win_dns_client
    win_dsc
    win_file
    win_firewall
    win_groupadd
    win_iis
    win_ip
    win_lgpo
    win_license
    win_network
    win_ntp
    win_path
    win_pkg
    win_pki
    win_powercfg
    win_psget
    win_repo
    win_servermanager
    win_service
    win_shadow
    win_smtp_server
    win_snmp
    win_status
    win_system
    win_task
    win_timezone
    win_update
    win_useradd
    win_wua
    x509
    xapi
    xbpspkg
    xfs
    xmpp
    yumpkg
    zabbix
    zcbuildout
    zenoss
    zfs
    zk_concurrency
    znc
    zpool
    zypper
